deranged library

Classes

AnyRange<C extends Comparable<C>>
A range supporting all possible Bounds.
Bound<C extends Comparable<C>>
One end of a range.
DoubleRange
DoubleRangeFrom
DoubleRangeFull
DoubleRangeInclusive
DoubleRangeTo
DoubleRangeToInclusive
ExclusiveBound<C extends Comparable<C>>
An exclusive end of a range.
InclusiveBound<C extends Comparable<C>>
An inclusive end of a range.
IntProgression
A Progression of int values, defined by a start, endInclusive, and step.
IntRange
IntRangeFrom
A range of int starting from an inclusive bound and without an end bound.
IntRangeFull
An unbounded range of int.
IntRangeTo
A range of int ending with an inclusive bound and without a start bound.
Progression<T>
A progression of values of type T, defined by a start, endInclusive, and step.
Range<C extends Comparable<C>>
A half-open range: start is included, end is excluded.
RangeBounds<C extends Comparable<C>>
Base class for Range & co., providing common methods.
RangeFrom<C extends Comparable<C>>
A range starting from an inclusive bound and without an end bound.
RangeFull<C extends Comparable<C>>
An unbounded range.
RangeInclusive<C extends Comparable<C>>
A closed range: both start and end are included.
RangeTo<C extends Comparable<C>>
A range ending with an exclusive bound and without a start bound.
RangeToInclusive<C extends Comparable<C>>
A range ending with an inclusive bound and without a start bound.
Step<C extends Step<C>>
Objects that have successor and predecessor operations.
StepProgression<T extends Step<T>>
A Progression of values of type T, defined by a start, endInclusive, and step.
UnboundedBound<C extends Comparable<C>>
An unbounded end of a range.