AnyRange<C extends Comparable<C> > class
A range supporting all possible Bounds.
- Inheritance
-
- Object
- RangeBounds<
C> - AnyRange
Constructors
-
AnyRange(InclusiveBound<
C> startBound, ExclusiveBound<C> endBound) -
const
Properties
-
endBound
→ ExclusiveBound<
C> -
The end bound of this range.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
startBound
→ InclusiveBound<
C> -
The start bound of this range.
final
Methods
-
contains(
C value) → bool -
Returns whether
valueis contained in this range.inherited -
containsRange(
RangeBounds< C> range) → bool -
Returns whether this range contains the entire other
range.inherited -
intersects(
RangeBounds< C> range) → bool -
Returns whether this and the other
rangehave at least one element in common.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited