Bound<C extends Comparable<C>> class sealed

One end of a range.

See also:

Implementers
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
isBounded bool
Whether this is a bound with an exact (inclusive or exclusive) value.
no setter
isUnbounded bool
Whether this is an UnboundedBound.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<D extends Comparable<D>>(D mapper(C)) Bound<D>
Maps the value of this bound using mapper.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited