DoubleRange class
- Inheritance
-
- Object
- RangeBounds<
num> - Range<
num> - DoubleRange
Constructors
- DoubleRange(num start, num end)
-
const
Properties
- end → double
-
no setteroverride
-
endBound
→ ExclusiveBound<
num> -
The end bound of this range.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → double
-
no setteroverride
-
startBound
→ InclusiveBound<
num> -
The start bound of this range.
no setterinherited
Methods
-
contains(
num value) → bool -
Returns whether
valueis contained in this range.override -
containsRange(
RangeBounds< num> range) → bool -
Returns whether this range contains the entire other
range.inherited -
intersects(
RangeBounds< num> range) → bool -
Returns whether this and the other
rangehave at least one element in common.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited