ExclusiveBound<C extends Comparable<C>> class final

An exclusive end of a range.

See also:

Inheritance

Constructors

ExclusiveBound(C value)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
inverted → Bound<C>
This bound as the opposite kind of edge: The end bound of everything before a start bound, and the start bound of everything after an end bound.
no setterinherited
isBounded → bool
Whether this is a bound with an exact (inclusive or exclusive) value.
no setteroverride
isUnbounded → bool
Whether this is an UnboundedBound.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → C
final
valueOrNull → C?
no setterinherited

Methods

cast<D extends Comparable<D>>() → ExclusiveBound<D>
Cast the value of this bound to D.
override
map<D extends Comparable<D>>(D mapper(C)) → ExclusiveBound<D>
Map the value of this bound using mapper.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override