RangeTo<C extends Comparable<C>> class

A range ending with an exclusive bound and without a start bound.

Inheritance
Implementers

Constructors

RangeTo(C end)
const

Properties

end → C
final
endBound ExclusiveBound<C>
The end bound of this range.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startBound UnboundedBound<C>
The start bound of this range.
no setteroverride

Methods

contains(C value) bool
Returns whether value is contained in this range.
inherited
containsRange(RangeBounds<C> range) bool
Returns whether this range contains the entire other range.
inherited
intersects(RangeBounds<C> range) bool
Returns whether this and the other range have at least one element in common.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited