RangeUntil<C extends Comparable<C>> class

A range ending with an exclusive bound and without a start bound.

Inheritance
Implementers
Available extensions

Constructors

RangeUntil(C end)
const

Properties

asRangeSet → RangeSet<C>
A RangeSet describing the same values as this.
no setterinherited
bounds → AnyRange<C>?
The smallest single range containing every value of this, or null if this is empty.
no setterinherited
end → C
final
endBound → ExclusiveBound<C>
The end bound of this range.
no setteroverride
endExclusive → T?

Available on RangeBounds<T>, provided by the DerangedRangeBoundsOfStep extension

Returns the exclusive end of this range, or null if this range has no bounded end.
no setter
endInclusive → T?

Available on RangeBounds<T>, provided by the DerangedRangeBoundsOfStep extension

Returns the inclusive end of this range, or null if this range has no bounded end.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this describes no values at all.
no setterinherited
isFull → bool
Whether this describes every value, i.e., the same values as a RangeFull.
no setterinherited
isNotEmpty → bool
Whether this describes at least one value.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startBound → UnboundedBound<C>
The start bound of this range.
no setteroverride
startExclusive → T?

Available on RangeBounds<T>, provided by the DerangedRangeBoundsOfStep extension

Returns the exclusive start of this range, or null if this range has no bounded start.
no setter
startInclusive → T?

Available on RangeBounds<T>, provided by the DerangedRangeBoundsOfStep extension

Returns the inclusive start of this range, or null if this range has no bounded start.
no setter

Methods

castBounds<D extends Comparable<D>>() → RangeUntil<D>
Returns this with every bound value cast to D.
override
clamp(T value) → T

Available on RangeBounds<T>, provided by the DerangedRangeBoundsOfStep extension

Returns value limited to this range.
contains(C value) → bool
Returns whether value is described by this.
inherited
containsAll(RangeLike<C> other) → bool
Returns whether every value of other is described by this.
inherited
copyWithBounds({Bound<C>? startBound, Bound<C>? endBound}) → AnyRange<C>
inherited
intersect(RangeBounds<C> other) → AnyRange<C>
The largest range containing only values of both this and other, i.e., their overlap. Empty if they have no values in common.
inherited
intersects(RangeLike<C> other) → bool
Returns whether this and other have at least one value in common.
inherited
mapBounds<D extends Comparable<D>>(D mapper(C)) → RangeUntil<D>
Returns this with every bound value mapped using mapper.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
span(RangeLike<C> other) → AnyRange<C>?
The smallest single range containing every value of this and other, or null if both are empty.
inherited
toString() → String
A string representation of this object.
override

Operators

operator &(RangeLike<C> other) → RangeSet<C>
Intersection of this and other, i.e., the values described by both.
inherited
operator -(RangeLike<C> other) → RangeSet<C>
Difference of this and other, i.e., the values described by this but not by other.
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator |(RangeLike<C> other) → RangeSet<C>
Union of this and other, i.e., every value described by either.
inherited
operator ~() → RangeSet<C>
Complement of this, i.e., the values it does not describe.
inherited