DoubleRangeToInclusive class
- Inheritance
-
- Object
- RangeBounds<
num> - RangeToInclusive<
num> - DoubleRangeToInclusive
Constructors
- DoubleRangeToInclusive(num endInclusive)
-
const
Properties
-
endBound
→ InclusiveBound<
num> -
The end bound of this range.
no setterinherited
- endExclusive → double
-
no setter
- endInclusive → double
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
startBound
→ UnboundedBound<
num> -
The start bound of this range.
no setterinherited
Methods
-
contains(
Object? value) → bool -
Returns whether
valueis contained in this range.override -
containsRange(
RangeBounds< num> range) → bool -
Returns whether this range contains the entire other
range.inherited -
intersects(
RangeBounds< num> range) → bool -
Returns whether this and the other
rangehave at least one element in common.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited