RangeBounds<C extends Comparable<C> > class
abstract
Base class for Range & co., providing common methods.
Here's an overview of the different subclasses:
| Start Bound | End Bound | Generic | For int | For double |
|---|---|---|---|---|
| Inclusive | Inclusive | RangeInclusive | IntRange | DoubleRangeInclusive |
| Inclusive | Exclusive | Range | IntRange | DoubleRange |
| Inclusive | Unbounded | RangeFrom | IntRangeFrom | DoubleRangeFrom |
| Exclusive | Inclusive | — | — | — |
| Exclusive | Exclusive | — | — | — |
| Exclusive | Unbounded | — | — | — |
| Unbounded | Inclusive | RangeToInclusive | IntRangeTo | DoubleRangeToInclusive |
| Unbounded | Exclusive | RangeTo | IntRangeTo | DoubleRangeTo |
| Unbounded | Unbounded | RangeFull | IntRangeFull | DoubleRangeFull |
- Implementers
- Annotations
-
- @immutable
Constructors
- RangeBounds()
-
const
Properties
-
endBound
→ Bound<
C> -
The end bound of this range.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
startBound
→ Bound<
C> -
The start bound of this range.
no setter
Methods
-
contains(
C value) → bool -
Returns whether
valueis contained in this range. -
containsRange(
RangeBounds< C> range) → bool -
Returns whether this range contains the entire other
range. -
intersects(
RangeBounds< C> range) → bool -
Returns whether this and the other
rangehave at least one element in common. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited