RangeInclusive<C extends Comparable<C> > class
A closed range: both start and end are included.
- Inheritance
-
- Object
- RangeBounds<
C> - RangeInclusive
- Implementers
- Available extensions
Constructors
- RangeInclusive(C start, C endInclusive)
-
const
- RangeInclusive.single(C value)
-
const
Properties
-
endBound
→ InclusiveBound<
C> -
The end bound of this range.
no setteroverride
- endInclusive → C
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → C
-
final
-
startBound
→ InclusiveBound<
C> -
The start bound of this range.
no setteroverride
Methods
-
contains(
C value) → bool -
Returns whether
valueis contained in this range.inherited -
containsRange(
RangeBounds< C> range) → bool -
Returns whether this range contains the entire other
range.inherited -
intersects(
RangeBounds< C> range) → bool -
Returns whether this and the other
rangehave at least one element in common.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stepBy(
int step) → StepProgression< T> -
Available on RangeInclusive<
Returns a StepProgression with this range's start and endInclusive, as well as the givenT> , provided by the RangeInclusiveOfStepExtension extensionstep. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited