Objects that have successor and predecessor operations.
- Implemented types
-
- Comparable<
C>
- Comparable<
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compareTo(
C other) → int -
Compares this object to another object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stepBy(
int count) → C -
Returns the result of moving
countsteps forward from this. -
stepsUntil(
C other) → int -
The number of steps between this and
other. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited